# @jupyterlab/docmanager

A JupyterLab package which handles interactions with documents and the file system.
It opens and closes files, creates new views onto files, and keeps track of open documents.

The `DocumentManager` should be considered a singleton for the application.
